<?php 

namespace Management\Services;

use Doctrine\ORM\EntityManager;
use Management\Util;

class ManageDashboardService {

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }

	public function getVendasMensais($CDFILIAL,$NRORG) {
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':NRORG' => $NRORG		
		);
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_MENSAIS, $params);
	}
	
	public function getObjetivoVendaDiaAlt($CDFILIAL,$NRORG,$CDOBJANO,$NRDIASEMANA,$DTALT,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':NRDIASEMANA'	=>	$NRDIASEMANA,
			':DTALT'		=>	$DTALT,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_DIA_ALT, $params);
	}
	
	public function getObjetivoVendaDia($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJDIA,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':CDOBJDIA'		=>	$CDOBJDIA,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_DIA, $params);
	}
	
	public function getObjetivoVendaMes($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_MES, $params);
	}
	
	public function getVendasDiarias($CDFILIAL, $DTENTRVENDA, $NRORG) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':DTENTRVENDA'	=>	$DTENTRVENDA,
			':NRORG'		=>	$NRORG
		);
		
		$vndsConc = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_DIARIAS_CONCLUIDAS, $params);
		$vndsCanc = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_DIARIAS_CANCELADAS, $params);
	
		return array_merge($vndsConc[0], $vndsCanc[0]);
	}
	
	public function getProdutosMaisVendidos($CDFILIAL, $DTENTRVENDA, $NRORG) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':DTENTRVENDA'	=>	$DTENTRVENDA,
			':NRORG'		=>	$NRORG
		);
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_PRODUTOS_MAIS_VENDIDOS, $params);
	}
	
	public function findDivergenciasConciliacao ($NRORG) {
		$params = array (
			':NRORG'	=> $NRORG
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::COUNT_DIVERGENCIAS_CONCILIACO, $params);
	}
	
	public function findFiliaisDoOperador ($CDOPERADOR, $NRORG) {
		$params = array (
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FILIAIS_OPERADOR, $params);
	}
	
	public function findConsolidacaoVendaPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':TODASNF'   => 'S'
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_CONSOLIDACAO_VENDA_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_CONSOLIDACAO_VENDA_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function findFechamentoCupomPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FECHAMENTO_CUPOM_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_FECHAMENTO_CUPOM_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function findFechamentoCaixaPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FECHAMENTO_CAIXA_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_FECHAMENTO_CAIXA_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function unidadeBloq($conditions){
		$params = array(
        		":NRORG"    	  => $conditions["NRORG"],
        		":CDFILIAL"		  => $conditions["CDFILIAL"],
        		":CDOPERADOR"     => $conditions["CDOPERADOR"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::GET_IS_FILIAL_BLOQ, $params);
		
	}
	
	public function perfilUtlBloq ($conditions){
		$params = array(
        		":NRORG"    			      => $conditions["NRORG"],
        		":NRPERFILACESSO"		  => $conditions["CDPERFILSELECIONADO"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::PERF_UTL_BLOQ, $params)['IDBLOCKFILIAL'] == 'N';
		
	}
	
	public function paramOperador ($conditions){
		$params = array(
        		":NRORG"    			      => $conditions["NRORG"],
        		":CDOPERADOR"		  => $conditions["CDOPERADOR"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::GET_PARAM_OPERADOR, $params);
		
	}
	
	public function paramPerfilSelecionado($nrorg, $cdoperador){
		$params = array(
        		":NRORG"    			      => $nrorg,
        		":CDOPERADOR"		  => $cdoperador
        	);
        return $this->entityManager->getConnection()->fetchAssoc(self::GET_PERFIL_OPERADOR, $params);
	}
	
	const GET_IS_FILIAL_BLOQ = "
		SELECT FILIAL.NMFILIAL,
		  FILIAL.NRORG,
		  FILIAL.IDSTATUSBLOQ
		FROM FILIAL
		INNER JOIN FILIOPER FI
		ON(FILIAL.CDFILIAL    = FI.CDFILIAL
		AND CDOPERADOR        = :CDOPERADOR
		AND FILIAL.NRORG      = FI.NRORG)
		WHERE FILIAL.NRORG    = :NRORG
		AND FILIAL.IDCNTRRESC = 'N'
		AND FILIAL.CDFILIAL = :CDFILIAL
		AND FILIAL.IDSTATUSBLOQ = 'S'
		ORDER BY FILIAL.CDFILIAL
	";
	
	const PERF_UTL_BLOQ = "
	SELECT IDBLOCKFILIAL 
		FROM PERFILACESSO 
		WHERE NRPERFILACESSO = :NRPERFILACESSO
			AND NRORG = :NRORG";
	
	const GET_PARAM_OPERADOR = "
	SELECT
	    O.CDPERFILSELECIONADO AS CDPERFILACESSO,
	    PF.NMPERFILACESSO,
	    O.CDOPERADOR
	FROM
	    OPERADOR       O
	    JOIN PERFILACESSO   PF 
	    	ON PF.NRPERFILACESSO = O.CDPERFILSELECIONADO
	WHERE
	    O.CDOPERADOR = :CDOPERADOR AND
	    O.NRORG 	 = :NRORG";
	    
	const GET_PERFIL_OPERADOR = "
	SELECT CDPERFILSELECIONADO FROM OPERADOR WHERE CDOPERADOR = :CDOPERADOR AND NRORG = :NRORG";
} 