/***********************************************************************/
/* Sistemas Integrados TECNISA                                         */
/*                                                                     */
/* Pedidos, Expedio                                                  */
/*                                                                     */
/***********************************************************************/
/*                                                                     */
/* Nome: 2850_PEDSTP_CONSISTE_PEDIDO                                   */
/*                                                                     */
/* Descrio:                                                          */
/*     Est procedure faz a consistencia do pedido. Ela  definida     */
/* pelo cliente. Ele pede para incluir um registro na tabela CONSPEDIDO*/
/* e define a forma como o sistema deve fazer a consistencia.          */
/*                                                                     */
/* Criao:                                                            */
/* 25/09/2003 - Andr Rodrigo                                          */
/*                                                                     */
/*                                                                     */
/* @C:\WIN_V3\SQL\END_CONV\ORACLE\2850_PEDSTP_CONSISTE_PEDIDO.SQL      */
/*                                                                     */
/* raise_application_error(-20501, :OLD.CDFILIAL||'-'||:OLD.NRPEDIDO||'-'||:OLD.NRITEMPED, True); */
/***********************************************************************/

CREATE OR REPLACE PROCEDURE GRAVA_INCONSPEDIDO (
       P_CDFILIAL     IN  ITEMPEDIDO.CDFILIAL%TYPE,
       P_NRPEDIDO     IN  ITEMPEDIDO.NRPEDIDO%TYPE,
       P_NRITEMPED    IN  ITEMPEDIDO.NRITEMPED%TYPE,
       P_CDCONSPEDIDO IN  INCONSPEDIDO.CDCONSPEDIDO%TYPE,
       P_IDINCONSLIB OUT  VARCHAR2)
IS
   V_NRINCONSPED   NUMBER;
   V_CTINCONS      NUMBER;
   V_CTCONSLIB     NUMBER;
BEGIN
   /* Verifica se j existe a inconsistcia no item do pedido */
   SELECT COUNT(*) INTO V_CTINCONS
   FROM INCONSPEDIDO
   WHERE (CDFILIAL     = P_CDFILIAL)
     AND (NRPEDIDO     = P_NRPEDIDO)
     AND (NRITEMPED    = P_NRITEMPED OR P_NRITEMPED IS NULL)
     AND (CDCONSPEDIDO = P_CDCONSPEDIDO);

   P_IDINCONSLIB := 'E';
   IF V_CTINCONS = 0 THEN
      SELECT NVL(MAX(NRINCONSPED), 0) + 1 INTO V_NRINCONSPED
      FROM INCONSPEDIDO
      WHERE CDFILIAL = P_CDFILIAL
        AND NRPEDIDO = P_NRPEDIDO;

      INSERT INTO INCONSPEDIDO
         (CDFILIAL, NRPEDIDO, NRINCONSPED, NRITEMPED, CDCONSPEDIDO)
      VALUES
         (P_CDFILIAL, P_NRPEDIDO, LPAD(TO_CHAR(V_NRINCONSPED), 3, '0'), P_NRITEMPED, P_CDCONSPEDIDO);

      P_IDINCONSLIB := 'E';
   ELSE
      /* Verifica se a inconsistcia j foi liberada */
      SELECT COUNT(*) INTO V_CTCONSLIB
      FROM INCONSPEDIDO
      WHERE (CDFILIAL     = P_CDFILIAL)
        AND (NRPEDIDO     = P_NRPEDIDO)
        AND (NRITEMPED    = P_NRITEMPED OR P_NRITEMPED IS NULL)
        AND (CDCONSPEDIDO = P_CDCONSPEDIDO)
        AND (DTLIBEINCONS IS NOT NULL);

      IF V_CTCONSLIB > 0 THEN
         P_IDINCONSLIB := 'L';
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('GRAVA_INCONSPEDIDO','4.05.125'); END;
/

